@@ -1,22 +1,11 @@
 /*
- * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
- * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- * Copyright 2007-2008 Pierre-Benoit Besse <besse@gmail.com>
- * Copyright 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Mathias Kraus <k.hias@gmx.de>
+    SPDX-FileCopyrightText: 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
+    SPDX-FileCopyrightText: 2007-2008 Pierre-Benoit Besse <besse@gmail.com>
+    SPDX-FileCopyrightText: 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "game.h"
 #include "mapparser.h"
@@ -575,7 +564,7 @@ void Game::decrementRemainingRoundTime()
             m_bombCount++;
             Bomb* bomb = new Bomb((nCol + 0.5) * Granatier::CellSize, (nRow + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 1000);    // time in ms
             bomb->setBombPower(static_cast<int>(granatier::RNG::fromRange(1.0, 2.5)));
-            emit bombCreated(bomb);
+            Q_EMIT bombCreated(bomb);
             connect(bomb, &Bomb::bombDetonated, this, &Game::bombDetonated);
             m_bombs.append(bomb);
             if(m_remainingTime > -100 && m_roundTimer->interval() > 150)
@@ -705,7 +694,7 @@ void Game::createBomb(Player* player, qreal x, qreal y, bool newBomb, int throwD
     m_bombCount++;
     Bomb* bomb = new Bomb((col + 0.5) * Granatier::CellSize, (row + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 2500);    // time in ms
     bomb->setBombPower(player->getBombPower());
-    emit bombCreated(bomb);
+    Q_EMIT bombCreated(bomb);
     connect(bomb, &Bomb::bombDetonated, this, &Game::bombDetonated);
     connect(bomb, &Bomb::releaseBombArmory, player, &Player::slot_refillBombArmory);
     m_bombs.append(bomb);
